@@ -72,6 +72,21 @@ def global_nan_percentage_graph(data):
     plt.legend(["Taux de valeurs manquantes", "Taux de remplissage"],
                shadow=True, loc="center", bbox_to_anchor=(.5, 0), ncol=2)
 
+def nan_columns_breakdown(data):
+    """Retourne un tableau avec le nombre de NaN et le taux de NaN, par variables.
+    data -- le dataFrame
+    """
+    nan_count = [] 
+    nan_percent = []
+    for col in data.columns:
+        v = data[col].isna().sum().sum()
+        nan_count.append(v)
+        nan_percent.append(round(v/data.shape[0]*100,2))
+    df_nan = pd.DataFrame([nan_count,nan_percent,data.columns]).T
+    df_nan.columns=["Nan count","% NaN","variables"]
+    df_nan.set_index("variables",inplace=True)
+    df_nan.sort_values(by="% NaN", ascending=False, inplace=True)
+    display(df_nan)
 
 def delete_nanfilled_cols(data, cutoff=.90, exclude=False, inplace=False):
     """Suppression des colomnes avec un certain seuil de nan
@@ -183,24 +198,42 @@ def df_descriptive_stats(data, features_list=False):
         data : le dataFrame
         features_list : list of columns (optional)
     """
+    num_variables = []
+    cat_variables = []
     if features_list:
         data = data[features_list]
-    df_temp = data.describe(include='all')
-    df_temp = df_temp.drop(
-        ["25%", "50%", "75%", "count"], axis=0, errors='ignore')
-    median = df_temp.median(skipna=True, numeric_only=True)
-    mode = df_temp.mode(dropna=True, numeric_only=True).iloc[0, :]
-    skew = df_temp.skew(skipna=True, numeric_only=True)
-    kurtosis = df_temp.kurtosis(skipna=True, numeric_only=True)
+        vtypes = data[features_list].dtypes
+    else:
+        data = data
+        vtypes = data.dtypes
+        
+    for v, vtype in zip(data, vtypes):
+        if vtype == float or vtype == int:
+            num_variables.append(v)
+        else:
+            cat_variables.append(v)
+        
+    if len(num_variables) > 0:
+        df_temp = data[num_variables].describe(include='all')
+        df_temp = df_temp.drop(
+            ["25%", "50%", "75%", "count"], axis=0, errors='ignore')
+        median = df_temp.median(skipna=True, numeric_only=True)
+        mode = df_temp.mode(dropna=True, numeric_only=True).iloc[0, :]
+        skew = df_temp.skew(skipna=True, numeric_only=True)
+        kurtosis = df_temp.kurtosis(skipna=True, numeric_only=True)
 
-    df_temp = df_temp.T
-    df_temp["median"] = median
-    df_temp["mode"] = mode
-    df_temp["skew"] = skew
-    df_temp["kurtosis"] = kurtosis
+        df_temp = df_temp.T
+        df_temp["median"] = median
+        df_temp["mode"] = mode
+        df_temp["skew"] = skew
+        df_temp["kurtosis"] = kurtosis
 
-    df_temp = df_temp.T
-    display(df_temp)
+        df_temp = df_temp.T
+        display(df_temp)
+        
+    if len(cat_variables) > 0:
+        df_temp = data[cat_variables].describe(include='all')
+        display(df_temp)
 
 
 def df_outlier_boxplot(series, title, borne_inf, borne_sup, outlier_inf=False, outlier_sup=False):
